@@ -11,6 +11,18 @@ class ScaffoldContext(dict):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self['steps'] = {}
+        self['colors'] = {
+            'PURPLE': '\033[35m',
+            'CYAN':  '\033[36m',
+            'BLUE':  '\033[34m',
+            'GREEN':  '\033[32m',
+            'YELLOW':  '\033[33m',
+            'RED':  '\033[31m',
+            'BOLD':  '\033[1m',
+            'UNDERLINE':  '\033[4m',
+            'ITALIC':  '\033[3m',
+            'END':  '\033[0m',
+        }
         self.notes = []
         self.todos = []
         self.environ = {}
