@@ -17,7 +17,7 @@ def init(context: ScaffoldPluginContext):
 
 
 def get_formatter(path, options):
-    default_formatter = TextConfigFormatter()
+    default_formatter = YamlConfigFormatter()
 
     formatters: List[ConfigFormatter] = [
         YamlConfigFormatter(),
